Class: PulpGemClient::RemotesGemApi
- Inherits:
-
Object
- Object
- PulpGemClient::RemotesGemApi
- Defined in:
- lib/pulp_gem_client/api/remotes_gem_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(gem_gem_remote, opts = {}) ⇒ GemGemRemoteResponse
Create a gem remote A ViewSet for GemRemote.
-
#create_with_http_info(gem_gem_remote, opts = {}) ⇒ Array<(GemGemRemoteResponse, Integer, Hash)>
Create a gem remote A ViewSet for GemRemote.
-
#delete(gem_gem_remote_href, opts = {}) ⇒ AsyncOperationResponse
Delete a gem remote Trigger an asynchronous delete task.
-
#delete_with_http_info(gem_gem_remote_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a gem remote Trigger an asynchronous delete task.
-
#initialize(api_client = ApiClient.default) ⇒ RemotesGemApi
constructor
A new instance of RemotesGemApi.
-
#list(opts = {}) ⇒ PaginatedgemGemRemoteResponseList
List gem remotes A ViewSet for GemRemote.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedgemGemRemoteResponseList, Integer, Hash)>
List gem remotes A ViewSet for GemRemote.
-
#partial_update(gem_gem_remote_href, patchedgem_gem_remote, opts = {}) ⇒ AsyncOperationResponse
Update a gem remote Trigger an asynchronous partial update task.
-
#partial_update_with_http_info(gem_gem_remote_href, patchedgem_gem_remote, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a gem remote Trigger an asynchronous partial update task.
-
#read(gem_gem_remote_href, opts = {}) ⇒ GemGemRemoteResponse
Inspect a gem remote A ViewSet for GemRemote.
-
#read_with_http_info(gem_gem_remote_href, opts = {}) ⇒ Array<(GemGemRemoteResponse, Integer, Hash)>
Inspect a gem remote A ViewSet for GemRemote.
-
#update(gem_gem_remote_href, gem_gem_remote, opts = {}) ⇒ AsyncOperationResponse
Update a gem remote Trigger an asynchronous update task.
-
#update_with_http_info(gem_gem_remote_href, gem_gem_remote, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a gem remote Trigger an asynchronous update task.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RemotesGemApi
Returns a new instance of RemotesGemApi.
19 20 21 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(gem_gem_remote, opts = {}) ⇒ GemGemRemoteResponse
Create a gem remote A ViewSet for GemRemote.
27 28 29 30 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 27 def create(gem_gem_remote, opts = {}) data, _status_code, _headers = create_with_http_info(gem_gem_remote, opts) data end |
#create_with_http_info(gem_gem_remote, opts = {}) ⇒ Array<(GemGemRemoteResponse, Integer, Hash)>
Create a gem remote A ViewSet for GemRemote.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 37 def create_with_http_info(gem_gem_remote, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RemotesGemApi.create ...' end # verify the required parameter 'gem_gem_remote' is set if @api_client.config.client_side_validation && gem_gem_remote.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_remote' when calling RemotesGemApi.create" end # resource path local_var_path = '/pulp/api/v3/remotes/gem/gem/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(gem_gem_remote) # return_type return_type = opts[:return_type] || 'GemGemRemoteResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RemotesGemApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete(gem_gem_remote_href, opts = {}) ⇒ AsyncOperationResponse
Delete a gem remote Trigger an asynchronous delete task
91 92 93 94 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 91 def delete(gem_gem_remote_href, opts = {}) data, _status_code, _headers = delete_with_http_info(gem_gem_remote_href, opts) data end |
#delete_with_http_info(gem_gem_remote_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a gem remote Trigger an asynchronous delete task
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 101 def delete_with_http_info(gem_gem_remote_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RemotesGemApi.delete ...' end # verify the required parameter 'gem_gem_remote_href' is set if @api_client.config.client_side_validation && gem_gem_remote_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_remote_href' when calling RemotesGemApi.delete" end # resource path local_var_path = '{gem_gem_remote_href}'.sub('{' + 'gem_gem_remote_href' + '}', CGI.escape(gem_gem_remote_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RemotesGemApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedgemGemRemoteResponseList
List gem remotes A ViewSet for GemRemote.
171 172 173 174 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 171 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedgemGemRemoteResponseList, Integer, Hash)>
List gem remotes A ViewSet for GemRemote.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 199 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RemotesGemApi.list ...' end allowable_values = ["-ca_cert", "-client_cert", "-client_key", "-connect_timeout", "-download_concurrency", "-headers", "-max_retries", "-name", "-password", "-pk", "-policy", "-proxy_password", "-proxy_url", "-proxy_username", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-rate_limit", "-sock_connect_timeout", "-sock_read_timeout", "-tls_validation", "-total_timeout", "-url", "-username", "ca_cert", "client_cert", "client_key", "connect_timeout", "download_concurrency", "headers", "max_retries", "name", "password", "pk", "policy", "proxy_password", "proxy_url", "proxy_username", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "rate_limit", "sock_connect_timeout", "sock_read_timeout", "tls_validation", "total_timeout", "url", "username"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/remotes/gem/gem/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil? query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil? query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil? query_params[:'name__startswith'] = opts[:'name__startswith'] if !opts[:'name__startswith'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'pulp_last_updated'] = opts[:'pulp_last_updated'] if !opts[:'pulp_last_updated'].nil? query_params[:'pulp_last_updated__gt'] = opts[:'pulp_last_updated__gt'] if !opts[:'pulp_last_updated__gt'].nil? query_params[:'pulp_last_updated__gte'] = opts[:'pulp_last_updated__gte'] if !opts[:'pulp_last_updated__gte'].nil? query_params[:'pulp_last_updated__lt'] = opts[:'pulp_last_updated__lt'] if !opts[:'pulp_last_updated__lt'].nil? query_params[:'pulp_last_updated__lte'] = opts[:'pulp_last_updated__lte'] if !opts[:'pulp_last_updated__lte'].nil? query_params[:'pulp_last_updated__range'] = @api_client.build_collection_param(opts[:'pulp_last_updated__range'], :csv) if !opts[:'pulp_last_updated__range'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'PaginatedgemGemRemoteResponseList' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RemotesGemApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#partial_update(gem_gem_remote_href, patchedgem_gem_remote, opts = {}) ⇒ AsyncOperationResponse
Update a gem remote Trigger an asynchronous partial update task
271 272 273 274 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 271 def partial_update(gem_gem_remote_href, patchedgem_gem_remote, opts = {}) data, _status_code, _headers = partial_update_with_http_info(gem_gem_remote_href, patchedgem_gem_remote, opts) data end |
#partial_update_with_http_info(gem_gem_remote_href, patchedgem_gem_remote, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a gem remote Trigger an asynchronous partial update task
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 282 def partial_update_with_http_info(gem_gem_remote_href, patchedgem_gem_remote, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RemotesGemApi.partial_update ...' end # verify the required parameter 'gem_gem_remote_href' is set if @api_client.config.client_side_validation && gem_gem_remote_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_remote_href' when calling RemotesGemApi.partial_update" end # verify the required parameter 'patchedgem_gem_remote' is set if @api_client.config.client_side_validation && patchedgem_gem_remote.nil? fail ArgumentError, "Missing the required parameter 'patchedgem_gem_remote' when calling RemotesGemApi.partial_update" end # resource path local_var_path = '{gem_gem_remote_href}'.sub('{' + 'gem_gem_remote_href' + '}', CGI.escape(gem_gem_remote_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(patchedgem_gem_remote) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RemotesGemApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(gem_gem_remote_href, opts = {}) ⇒ GemGemRemoteResponse
Inspect a gem remote A ViewSet for GemRemote.
342 343 344 345 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 342 def read(gem_gem_remote_href, opts = {}) data, _status_code, _headers = read_with_http_info(gem_gem_remote_href, opts) data end |
#read_with_http_info(gem_gem_remote_href, opts = {}) ⇒ Array<(GemGemRemoteResponse, Integer, Hash)>
Inspect a gem remote A ViewSet for GemRemote.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 354 def read_with_http_info(gem_gem_remote_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RemotesGemApi.read ...' end # verify the required parameter 'gem_gem_remote_href' is set if @api_client.config.client_side_validation && gem_gem_remote_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_remote_href' when calling RemotesGemApi.read" end # resource path local_var_path = '{gem_gem_remote_href}'.sub('{' + 'gem_gem_remote_href' + '}', CGI.escape(gem_gem_remote_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'GemGemRemoteResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RemotesGemApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update(gem_gem_remote_href, gem_gem_remote, opts = {}) ⇒ AsyncOperationResponse
Update a gem remote Trigger an asynchronous update task
409 410 411 412 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 409 def update(gem_gem_remote_href, gem_gem_remote, opts = {}) data, _status_code, _headers = update_with_http_info(gem_gem_remote_href, gem_gem_remote, opts) data end |
#update_with_http_info(gem_gem_remote_href, gem_gem_remote, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a gem remote Trigger an asynchronous update task
420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/pulp_gem_client/api/remotes_gem_api.rb', line 420 def update_with_http_info(gem_gem_remote_href, gem_gem_remote, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RemotesGemApi.update ...' end # verify the required parameter 'gem_gem_remote_href' is set if @api_client.config.client_side_validation && gem_gem_remote_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_remote_href' when calling RemotesGemApi.update" end # verify the required parameter 'gem_gem_remote' is set if @api_client.config.client_side_validation && gem_gem_remote.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_remote' when calling RemotesGemApi.update" end # resource path local_var_path = '{gem_gem_remote_href}'.sub('{' + 'gem_gem_remote_href' + '}', CGI.escape(gem_gem_remote_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(gem_gem_remote) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RemotesGemApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |