Class: PulpGemClient::RepositoriesGemApi
- Inherits:
-
Object
- Object
- PulpGemClient::RepositoriesGemApi
- Defined in:
- lib/pulp_gem_client/api/repositories_gem_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(gem_gem_repository, opts = {}) ⇒ GemGemRepositoryResponse
Create a gem repository A ViewSet for GemRepository.
-
#create_with_http_info(gem_gem_repository, opts = {}) ⇒ Array<(GemGemRepositoryResponse, Integer, Hash)>
Create a gem repository A ViewSet for GemRepository.
-
#delete(gem_gem_repository_href, opts = {}) ⇒ AsyncOperationResponse
Delete a gem repository Trigger an asynchronous delete task.
-
#delete_with_http_info(gem_gem_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a gem repository Trigger an asynchronous delete task.
-
#initialize(api_client = ApiClient.default) ⇒ RepositoriesGemApi
constructor
A new instance of RepositoriesGemApi.
-
#list(opts = {}) ⇒ PaginatedgemGemRepositoryResponseList
List gem repositorys A ViewSet for GemRepository.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedgemGemRepositoryResponseList, Integer, Hash)>
List gem repositorys A ViewSet for GemRepository.
-
#modify(gem_gem_repository_href, repository_add_remove_content, opts = {}) ⇒ AsyncOperationResponse
Modify Repository Content Trigger an asynchronous task to create a new repository version.
-
#modify_with_http_info(gem_gem_repository_href, repository_add_remove_content, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Modify Repository Content Trigger an asynchronous task to create a new repository version.
-
#partial_update(gem_gem_repository_href, patchedgem_gem_repository, opts = {}) ⇒ AsyncOperationResponse
Update a gem repository Trigger an asynchronous partial update task.
-
#partial_update_with_http_info(gem_gem_repository_href, patchedgem_gem_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a gem repository Trigger an asynchronous partial update task.
-
#read(gem_gem_repository_href, opts = {}) ⇒ GemGemRepositoryResponse
Inspect a gem repository A ViewSet for GemRepository.
-
#read_with_http_info(gem_gem_repository_href, opts = {}) ⇒ Array<(GemGemRepositoryResponse, Integer, Hash)>
Inspect a gem repository A ViewSet for GemRepository.
-
#set_label(gem_gem_repository_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
-
#set_label_with_http_info(gem_gem_repository_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
-
#sync(gem_gem_repository_href, repository_sync_url, opts = {}) ⇒ AsyncOperationResponse
Sync from a remote Trigger an asynchronous task to sync gem content.
-
#sync_with_http_info(gem_gem_repository_href, repository_sync_url, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sync from a remote Trigger an asynchronous task to sync gem content.
-
#unset_label(gem_gem_repository_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
-
#unset_label_with_http_info(gem_gem_repository_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
-
#update(gem_gem_repository_href, gem_gem_repository, opts = {}) ⇒ AsyncOperationResponse
Update a gem repository Trigger an asynchronous update task.
-
#update_with_http_info(gem_gem_repository_href, gem_gem_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a gem repository Trigger an asynchronous update task.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RepositoriesGemApi
Returns a new instance of RepositoriesGemApi.
19 20 21 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(gem_gem_repository, opts = {}) ⇒ GemGemRepositoryResponse
Create a gem repository A ViewSet for GemRepository.
27 28 29 30 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 27 def create(gem_gem_repository, opts = {}) data, _status_code, _headers = create_with_http_info(gem_gem_repository, opts) data end |
#create_with_http_info(gem_gem_repository, opts = {}) ⇒ Array<(GemGemRepositoryResponse, Integer, Hash)>
Create a gem repository A ViewSet for GemRepository.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 37 def create_with_http_info(gem_gem_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.create ...' end # verify the required parameter 'gem_gem_repository' is set if @api_client.config.client_side_validation && gem_gem_repository.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository' when calling RepositoriesGemApi.create" end # resource path local_var_path = '/pulp/api/v3/repositories/gem/gem/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(gem_gem_repository) # return_type return_type = opts[:return_type] || 'GemGemRepositoryResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete(gem_gem_repository_href, opts = {}) ⇒ AsyncOperationResponse
Delete a gem repository Trigger an asynchronous delete task
91 92 93 94 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 91 def delete(gem_gem_repository_href, opts = {}) data, _status_code, _headers = delete_with_http_info(gem_gem_repository_href, opts) data end |
#delete_with_http_info(gem_gem_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a gem repository Trigger an asynchronous delete task
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 101 def delete_with_http_info(gem_gem_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.delete ...' end # verify the required parameter 'gem_gem_repository_href' is set if @api_client.config.client_side_validation && gem_gem_repository_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository_href' when calling RepositoriesGemApi.delete" end # resource path local_var_path = '{gem_gem_repository_href}'.sub('{' + 'gem_gem_repository_href' + '}', CGI.escape(gem_gem_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedgemGemRepositoryResponseList
List gem repositorys A ViewSet for GemRepository.
179 180 181 182 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 179 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedgemGemRepositoryResponseList, Integer, Hash)>
List gem repositorys A ViewSet for GemRepository.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 215 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.list ...' end allowable_values = ["-description", "-name", "-next_version", "-pk", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-retain_repo_versions", "-user_hidden", "description", "name", "next_version", "pk", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "retain_repo_versions", "user_hidden"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/repositories/gem/gem/' # query parameters query_params = opts[:query_params] || {} query_params[:'latest_with_content'] = opts[:'latest_with_content'] if !opts[:'latest_with_content'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil? query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil? query_params[:'name__iexact'] = opts[:'name__iexact'] if !opts[:'name__iexact'].nil? query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil? query_params[:'name__istartswith'] = opts[:'name__istartswith'] if !opts[:'name__istartswith'].nil? query_params[:'name__startswith'] = opts[:'name__startswith'] if !opts[:'name__startswith'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'remote'] = opts[:'remote'] if !opts[:'remote'].nil? query_params[:'retain_repo_versions'] = opts[:'retain_repo_versions'] if !opts[:'retain_repo_versions'].nil? query_params[:'retain_repo_versions__gt'] = opts[:'retain_repo_versions__gt'] if !opts[:'retain_repo_versions__gt'].nil? query_params[:'retain_repo_versions__gte'] = opts[:'retain_repo_versions__gte'] if !opts[:'retain_repo_versions__gte'].nil? query_params[:'retain_repo_versions__isnull'] = opts[:'retain_repo_versions__isnull'] if !opts[:'retain_repo_versions__isnull'].nil? query_params[:'retain_repo_versions__lt'] = opts[:'retain_repo_versions__lt'] if !opts[:'retain_repo_versions__lt'].nil? query_params[:'retain_repo_versions__lte'] = opts[:'retain_repo_versions__lte'] if !opts[:'retain_repo_versions__lte'].nil? query_params[:'retain_repo_versions__ne'] = opts[:'retain_repo_versions__ne'] if !opts[:'retain_repo_versions__ne'].nil? query_params[:'retain_repo_versions__range'] = @api_client.build_collection_param(opts[:'retain_repo_versions__range'], :csv) if !opts[:'retain_repo_versions__range'].nil? query_params[:'with_content'] = opts[:'with_content'] if !opts[:'with_content'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'PaginatedgemGemRepositoryResponseList' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#modify(gem_gem_repository_href, repository_add_remove_content, opts = {}) ⇒ AsyncOperationResponse
Modify Repository Content Trigger an asynchronous task to create a new repository version.
295 296 297 298 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 295 def modify(gem_gem_repository_href, repository_add_remove_content, opts = {}) data, _status_code, _headers = modify_with_http_info(gem_gem_repository_href, repository_add_remove_content, opts) data end |
#modify_with_http_info(gem_gem_repository_href, repository_add_remove_content, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Modify Repository Content Trigger an asynchronous task to create a new repository version.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 306 def modify_with_http_info(gem_gem_repository_href, repository_add_remove_content, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.modify ...' end # verify the required parameter 'gem_gem_repository_href' is set if @api_client.config.client_side_validation && gem_gem_repository_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository_href' when calling RepositoriesGemApi.modify" end # verify the required parameter 'repository_add_remove_content' is set if @api_client.config.client_side_validation && repository_add_remove_content.nil? fail ArgumentError, "Missing the required parameter 'repository_add_remove_content' when calling RepositoriesGemApi.modify" end # resource path local_var_path = '{gem_gem_repository_href}modify/'.sub('{' + 'gem_gem_repository_href' + '}', CGI.escape(gem_gem_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(repository_add_remove_content) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#modify\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#partial_update(gem_gem_repository_href, patchedgem_gem_repository, opts = {}) ⇒ AsyncOperationResponse
Update a gem repository Trigger an asynchronous partial update task
365 366 367 368 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 365 def partial_update(gem_gem_repository_href, patchedgem_gem_repository, opts = {}) data, _status_code, _headers = partial_update_with_http_info(gem_gem_repository_href, patchedgem_gem_repository, opts) data end |
#partial_update_with_http_info(gem_gem_repository_href, patchedgem_gem_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a gem repository Trigger an asynchronous partial update task
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 376 def partial_update_with_http_info(gem_gem_repository_href, patchedgem_gem_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.partial_update ...' end # verify the required parameter 'gem_gem_repository_href' is set if @api_client.config.client_side_validation && gem_gem_repository_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository_href' when calling RepositoriesGemApi.partial_update" end # verify the required parameter 'patchedgem_gem_repository' is set if @api_client.config.client_side_validation && patchedgem_gem_repository.nil? fail ArgumentError, "Missing the required parameter 'patchedgem_gem_repository' when calling RepositoriesGemApi.partial_update" end # resource path local_var_path = '{gem_gem_repository_href}'.sub('{' + 'gem_gem_repository_href' + '}', CGI.escape(gem_gem_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(patchedgem_gem_repository) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(gem_gem_repository_href, opts = {}) ⇒ GemGemRepositoryResponse
Inspect a gem repository A ViewSet for GemRepository.
436 437 438 439 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 436 def read(gem_gem_repository_href, opts = {}) data, _status_code, _headers = read_with_http_info(gem_gem_repository_href, opts) data end |
#read_with_http_info(gem_gem_repository_href, opts = {}) ⇒ Array<(GemGemRepositoryResponse, Integer, Hash)>
Inspect a gem repository A ViewSet for GemRepository.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 448 def read_with_http_info(gem_gem_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.read ...' end # verify the required parameter 'gem_gem_repository_href' is set if @api_client.config.client_side_validation && gem_gem_repository_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository_href' when calling RepositoriesGemApi.read" end # resource path local_var_path = '{gem_gem_repository_href}'.sub('{' + 'gem_gem_repository_href' + '}', CGI.escape(gem_gem_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'GemGemRepositoryResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_label(gem_gem_repository_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
503 504 505 506 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 503 def set_label(gem_gem_repository_href, set_label, opts = {}) data, _status_code, _headers = set_label_with_http_info(gem_gem_repository_href, set_label, opts) data end |
#set_label_with_http_info(gem_gem_repository_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 514 def set_label_with_http_info(gem_gem_repository_href, set_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.set_label ...' end # verify the required parameter 'gem_gem_repository_href' is set if @api_client.config.client_side_validation && gem_gem_repository_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository_href' when calling RepositoriesGemApi.set_label" end # verify the required parameter 'set_label' is set if @api_client.config.client_side_validation && set_label.nil? fail ArgumentError, "Missing the required parameter 'set_label' when calling RepositoriesGemApi.set_label" end # resource path local_var_path = '{gem_gem_repository_href}set_label/'.sub('{' + 'gem_gem_repository_href' + '}', CGI.escape(gem_gem_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(set_label) # return_type return_type = opts[:return_type] || 'SetLabelResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#set_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sync(gem_gem_repository_href, repository_sync_url, opts = {}) ⇒ AsyncOperationResponse
Sync from a remote Trigger an asynchronous task to sync gem content.
573 574 575 576 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 573 def sync(gem_gem_repository_href, repository_sync_url, opts = {}) data, _status_code, _headers = sync_with_http_info(gem_gem_repository_href, repository_sync_url, opts) data end |
#sync_with_http_info(gem_gem_repository_href, repository_sync_url, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sync from a remote Trigger an asynchronous task to sync gem content.
584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 584 def sync_with_http_info(gem_gem_repository_href, repository_sync_url, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.sync ...' end # verify the required parameter 'gem_gem_repository_href' is set if @api_client.config.client_side_validation && gem_gem_repository_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository_href' when calling RepositoriesGemApi.sync" end # verify the required parameter 'repository_sync_url' is set if @api_client.config.client_side_validation && repository_sync_url.nil? fail ArgumentError, "Missing the required parameter 'repository_sync_url' when calling RepositoriesGemApi.sync" end # resource path local_var_path = '{gem_gem_repository_href}sync/'.sub('{' + 'gem_gem_repository_href' + '}', CGI.escape(gem_gem_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(repository_sync_url) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#sync\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#unset_label(gem_gem_repository_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
643 644 645 646 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 643 def unset_label(gem_gem_repository_href, unset_label, opts = {}) data, _status_code, _headers = unset_label_with_http_info(gem_gem_repository_href, unset_label, opts) data end |
#unset_label_with_http_info(gem_gem_repository_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 654 def unset_label_with_http_info(gem_gem_repository_href, unset_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.unset_label ...' end # verify the required parameter 'gem_gem_repository_href' is set if @api_client.config.client_side_validation && gem_gem_repository_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository_href' when calling RepositoriesGemApi.unset_label" end # verify the required parameter 'unset_label' is set if @api_client.config.client_side_validation && unset_label.nil? fail ArgumentError, "Missing the required parameter 'unset_label' when calling RepositoriesGemApi.unset_label" end # resource path local_var_path = '{gem_gem_repository_href}unset_label/'.sub('{' + 'gem_gem_repository_href' + '}', CGI.escape(gem_gem_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(unset_label) # return_type return_type = opts[:return_type] || 'UnsetLabelResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#unset_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update(gem_gem_repository_href, gem_gem_repository, opts = {}) ⇒ AsyncOperationResponse
Update a gem repository Trigger an asynchronous update task
713 714 715 716 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 713 def update(gem_gem_repository_href, gem_gem_repository, opts = {}) data, _status_code, _headers = update_with_http_info(gem_gem_repository_href, gem_gem_repository, opts) data end |
#update_with_http_info(gem_gem_repository_href, gem_gem_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a gem repository Trigger an asynchronous update task
724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'lib/pulp_gem_client/api/repositories_gem_api.rb', line 724 def update_with_http_info(gem_gem_repository_href, gem_gem_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesGemApi.update ...' end # verify the required parameter 'gem_gem_repository_href' is set if @api_client.config.client_side_validation && gem_gem_repository_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository_href' when calling RepositoriesGemApi.update" end # verify the required parameter 'gem_gem_repository' is set if @api_client.config.client_side_validation && gem_gem_repository.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_repository' when calling RepositoriesGemApi.update" end # resource path local_var_path = '{gem_gem_repository_href}'.sub('{' + 'gem_gem_repository_href' + '}', CGI.escape(gem_gem_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(gem_gem_repository) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesGemApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |