Class: PulpGemClient::ContentGemApi
- Inherits:
-
Object
- Object
- PulpGemClient::ContentGemApi
- Defined in:
- lib/pulp_gem_client/api/content_gem_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(opts = {}) ⇒ AsyncOperationResponse
Create a gem content Trigger an asynchronous task to create content,optionally create new repository version.
-
#create_with_http_info(opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a gem content Trigger an asynchronous task to create content,optionally create new repository version.
-
#initialize(api_client = ApiClient.default) ⇒ ContentGemApi
constructor
A new instance of ContentGemApi.
-
#list(opts = {}) ⇒ PaginatedgemGemContentResponseList
List gem contents A ViewSet for GemContent.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedgemGemContentResponseList, Integer, Hash)>
List gem contents A ViewSet for GemContent.
-
#read(gem_gem_content_href, opts = {}) ⇒ GemGemContentResponse
Inspect a gem content A ViewSet for GemContent.
-
#read_with_http_info(gem_gem_content_href, opts = {}) ⇒ Array<(GemGemContentResponse, Integer, Hash)>
Inspect a gem content A ViewSet for GemContent.
-
#set_label(gem_gem_content_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
-
#set_label_with_http_info(gem_gem_content_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
-
#unset_label(gem_gem_content_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
-
#unset_label_with_http_info(gem_gem_content_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContentGemApi
Returns a new instance of ContentGemApi.
19 20 21 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(opts = {}) ⇒ AsyncOperationResponse
Create a gem content Trigger an asynchronous task to create content,optionally create new repository version.
35 36 37 38 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 35 def create(opts = {}) data, _status_code, _headers = create_with_http_info(opts) data end |
#create_with_http_info(opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a gem content Trigger an asynchronous task to create content,optionally create new repository version.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 53 def create_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentGemApi.create ...' end if @api_client.config.client_side_validation && !opts[:'file_url'].nil? && opts[:'file_url'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"file_url"]" when calling ContentGemApi.create, the character length must be great than or equal to 1.' end # resource path local_var_path = '/pulp/api/v3/content/gem/gem/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data', 'application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} form_params['repository'] = opts[:'repository'] if !opts[:'repository'].nil? form_params['overwrite'] = opts[:'overwrite'] if !opts[:'overwrite'].nil? form_params['pulp_labels'] = opts[:'pulp_labels'] if !opts[:'pulp_labels'].nil? form_params['file'] = opts[:'file'] if !opts[:'file'].nil? form_params['upload'] = opts[:'upload'] if !opts[:'upload'].nil? form_params['file_url'] = opts[:'file_url'] if !opts[:'file_url'].nil? form_params['downloader_config'] = opts[:'downloader_config'] if !opts[:'downloader_config'].nil? form_params['artifact'] = opts[:'artifact'] if !opts[:'artifact'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentGemApi.create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentGemApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedgemGemContentResponseList
List gem contents A ViewSet for GemContent.
138 139 140 141 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 138 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedgemGemContentResponseList, Integer, Hash)>
List gem contents A ViewSet for GemContent.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 166 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentGemApi.list ...' end allowable_values = ["-checksum", "-dependencies", "-name", "-pk", "-platform", "-prerelease", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-required_ruby_version", "-required_rubygems_version", "-timestamp_of_interest", "-upstream_id", "-version", "checksum", "dependencies", "name", "pk", "platform", "prerelease", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "required_ruby_version", "required_rubygems_version", "timestamp_of_interest", "upstream_id", "version"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/content/gem/gem/' # query parameters query_params = opts[:query_params] || {} query_params[:'checksum'] = opts[:'checksum'] if !opts[:'checksum'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'orphaned_for'] = opts[:'orphaned_for'] if !opts[:'orphaned_for'].nil? query_params[:'prerelease'] = opts[:'prerelease'] if !opts[:'prerelease'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'repository_version'] = opts[:'repository_version'] if !opts[:'repository_version'].nil? query_params[:'repository_version_added'] = opts[:'repository_version_added'] if !opts[:'repository_version_added'].nil? query_params[:'repository_version_removed'] = opts[:'repository_version_removed'] if !opts[:'repository_version_removed'].nil? query_params[:'version'] = opts[:'version'] if !opts[:'version'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedgemGemContentResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentGemApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentGemApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(gem_gem_content_href, opts = {}) ⇒ GemGemContentResponse
Inspect a gem content A ViewSet for GemContent.
241 242 243 244 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 241 def read(gem_gem_content_href, opts = {}) data, _status_code, _headers = read_with_http_info(gem_gem_content_href, opts) data end |
#read_with_http_info(gem_gem_content_href, opts = {}) ⇒ Array<(GemGemContentResponse, Integer, Hash)>
Inspect a gem content A ViewSet for GemContent.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 254 def read_with_http_info(gem_gem_content_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentGemApi.read ...' end # verify the required parameter 'gem_gem_content_href' is set if @api_client.config.client_side_validation && gem_gem_content_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_content_href' when calling ContentGemApi.read" end # resource path local_var_path = '{gem_gem_content_href}'.sub('{' + 'gem_gem_content_href' + '}', CGI.escape(gem_gem_content_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GemGemContentResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentGemApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentGemApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_label(gem_gem_content_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
312 313 314 315 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 312 def set_label(gem_gem_content_href, set_label, opts = {}) data, _status_code, _headers = set_label_with_http_info(gem_gem_content_href, set_label, opts) data end |
#set_label_with_http_info(gem_gem_content_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 324 def set_label_with_http_info(gem_gem_content_href, set_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentGemApi.set_label ...' end # verify the required parameter 'gem_gem_content_href' is set if @api_client.config.client_side_validation && gem_gem_content_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_content_href' when calling ContentGemApi.set_label" end # verify the required parameter 'set_label' is set if @api_client.config.client_side_validation && set_label.nil? fail ArgumentError, "Missing the required parameter 'set_label' when calling ContentGemApi.set_label" end # resource path local_var_path = '{gem_gem_content_href}set_label/'.sub('{' + 'gem_gem_content_href' + '}', CGI.escape(gem_gem_content_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(set_label) # return_type return_type = opts[:debug_return_type] || 'SetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentGemApi.set_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentGemApi#set_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#unset_label(gem_gem_content_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
389 390 391 392 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 389 def unset_label(gem_gem_content_href, unset_label, opts = {}) data, _status_code, _headers = unset_label_with_http_info(gem_gem_content_href, unset_label, opts) data end |
#unset_label_with_http_info(gem_gem_content_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 401 def unset_label_with_http_info(gem_gem_content_href, unset_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentGemApi.unset_label ...' end # verify the required parameter 'gem_gem_content_href' is set if @api_client.config.client_side_validation && gem_gem_content_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_content_href' when calling ContentGemApi.unset_label" end # verify the required parameter 'unset_label' is set if @api_client.config.client_side_validation && unset_label.nil? fail ArgumentError, "Missing the required parameter 'unset_label' when calling ContentGemApi.unset_label" end # resource path local_var_path = '{gem_gem_content_href}unset_label/'.sub('{' + 'gem_gem_content_href' + '}', CGI.escape(gem_gem_content_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(unset_label) # return_type return_type = opts[:debug_return_type] || 'UnsetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentGemApi.unset_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentGemApi#unset_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |