Class: PulpGemClient::ContentGemApi
- Inherits:
-
Object
- Object
- PulpGemClient::ContentGemApi
- Defined in:
- lib/pulp_gem_client/api/content_gem_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(opts = {}) ⇒ AsyncOperationResponse
Create a gem content Trigger an asynchronous task to create content,optionally create new repository version.
-
#create_with_http_info(opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a gem content Trigger an asynchronous task to create content,optionally create new repository version.
-
#initialize(api_client = ApiClient.default) ⇒ ContentGemApi
constructor
A new instance of ContentGemApi.
-
#list(opts = {}) ⇒ PaginatedgemGemContentResponseList
List gem contents A ViewSet for GemContent.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedgemGemContentResponseList, Integer, Hash)>
List gem contents A ViewSet for GemContent.
-
#read(gem_gem_content_href, opts = {}) ⇒ GemGemContentResponse
Inspect a gem content A ViewSet for GemContent.
-
#read_with_http_info(gem_gem_content_href, opts = {}) ⇒ Array<(GemGemContentResponse, Integer, Hash)>
Inspect a gem content A ViewSet for GemContent.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContentGemApi
Returns a new instance of ContentGemApi.
19 20 21 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(opts = {}) ⇒ AsyncOperationResponse
Create a gem content Trigger an asynchronous task to create content,optionally create new repository version.
29 30 31 32 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 29 def create(opts = {}) data, _status_code, _headers = create_with_http_info(opts) data end |
#create_with_http_info(opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a gem content Trigger an asynchronous task to create content,optionally create new repository version.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 41 def create_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentGemApi.create ...' end # resource path local_var_path = '/pulp/api/v3/content/gem/gem/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data', 'application/x-www-form-urlencoded']) # form parameters form_params = opts[:form_params] || {} form_params['artifact'] = opts[:'artifact'] if !opts[:'artifact'].nil? form_params['file'] = opts[:'file'] if !opts[:'file'].nil? form_params['repository'] = opts[:'repository'] if !opts[:'repository'].nil? # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentGemApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedgemGemContentResponseList
List gem contents A ViewSet for GemContent.
107 108 109 110 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 107 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedgemGemContentResponseList, Integer, Hash)>
List gem contents A ViewSet for GemContent.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 130 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentGemApi.list ...' end allowable_values = ["-checksum", "-dependencies", "-name", "-pk", "-prerelease", "-pulp_created", "-pulp_id", "-pulp_last_updated", "-pulp_type", "-required_ruby_version", "-required_rubygems_version", "-timestamp_of_interest", "-upstream_id", "-version", "checksum", "dependencies", "name", "pk", "prerelease", "pulp_created", "pulp_id", "pulp_last_updated", "pulp_type", "required_ruby_version", "required_rubygems_version", "timestamp_of_interest", "upstream_id", "version"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/content/gem/gem/' # query parameters query_params = opts[:query_params] || {} query_params[:'checksum'] = opts[:'checksum'] if !opts[:'checksum'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'prerelease'] = opts[:'prerelease'] if !opts[:'prerelease'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'repository_version'] = opts[:'repository_version'] if !opts[:'repository_version'].nil? query_params[:'repository_version_added'] = opts[:'repository_version_added'] if !opts[:'repository_version_added'].nil? query_params[:'repository_version_removed'] = opts[:'repository_version_removed'] if !opts[:'repository_version_removed'].nil? query_params[:'version'] = opts[:'version'] if !opts[:'version'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'PaginatedgemGemContentResponseList' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentGemApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(gem_gem_content_href, opts = {}) ⇒ GemGemContentResponse
Inspect a gem content A ViewSet for GemContent.
198 199 200 201 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 198 def read(gem_gem_content_href, opts = {}) data, _status_code, _headers = read_with_http_info(gem_gem_content_href, opts) data end |
#read_with_http_info(gem_gem_content_href, opts = {}) ⇒ Array<(GemGemContentResponse, Integer, Hash)>
Inspect a gem content A ViewSet for GemContent.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/pulp_gem_client/api/content_gem_api.rb', line 210 def read_with_http_info(gem_gem_content_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentGemApi.read ...' end # verify the required parameter 'gem_gem_content_href' is set if @api_client.config.client_side_validation && gem_gem_content_href.nil? fail ArgumentError, "Missing the required parameter 'gem_gem_content_href' when calling ContentGemApi.read" end # resource path local_var_path = '{gem_gem_content_href}'.sub('{' + 'gem_gem_content_href' + '}', CGI.escape(gem_gem_content_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'GemGemContentResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentGemApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |